"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rehype = require("rehype");
function postProcessHtml(log, createDocMessage) {
    return new PostProcessHtml(log, createDocMessage);
}
exports.postProcessHtml = postProcessHtml;
/**
 * @dgProcessor postProcessHtml
 *
 * @description
 * Use the rehype processing engine to manipulate the
 * `renderedContent` HTML via rehype "plugins" that work with HTML ASTs (HASTs).
 * See https://github.com/rehypejs/rehype
 *
 * Each plugin is a factory function that will be called with the "rehype" engine as `this`.
 * The factory should return a "transform" function that takes a HAST and returns a `boolean` or `undefined`.
 * The HAST can be mutated by the "transform" function.
 * If `false` is returned then the processing stops with that plugin.
 *
 */
var PostProcessHtml = /** @class */ (function () {
    function PostProcessHtml(log, createDocMessage) {
        this.log = log;
        this.createDocMessage = createDocMessage;
        this.$runAfter = ['docs-rendered'];
        this.$runBefore = ['writing-files'];
        this.docTypes = [];
        this.plugins = [];
    }
    PostProcessHtml.prototype.$process = function (docs) {
        var _this = this;
        var engine = rehype().data('settings', { fragment: true });
        this.plugins.forEach(function (plugin) { return engine.use(plugin); });
        var vFile;
        docs
            .filter(function (doc) { return _this.docTypes.indexOf(doc.docType) !== -1; })
            .forEach(function (doc) {
            try {
                vFile = engine.processSync(doc.renderedContent);
                doc.renderedContent = vFile.contents.toString();
                vFile.messages.forEach(function (message) {
                    return _this.log.warn(_this.createDocMessage(message.message, doc));
                });
                doc.vFile = vFile;
            }
            catch (e) {
                throw new Error(_this.createDocMessage(e.message, doc));
            }
        });
    };
    return PostProcessHtml;
}());
exports.PostProcessHtml = PostProcessHtml;
//# sourceMappingURL=postProcessHtml.js.map