"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dgeni_1 = require("dgeni");
var mockPackage_1 = require("../mocks/mockPackage");
describe('postProcessHtml', function () {
    var dgeni;
    var injector;
    var processor;
    var createDocMessage;
    beforeEach(function () {
        dgeni = new dgeni_1.Dgeni([mockPackage_1.mockPackage(true)]);
        injector = dgeni.configureInjector();
        createDocMessage = injector.get('createDocMessage');
        processor = injector.get('postProcessHtml');
        processor.docTypes = ['a', 'b'];
    });
    it('should be available from the injector', function () {
        expect(processor).toBeDefined();
    });
    it('should only process docs that match the specified docTypes', function () {
        var elements = [];
        var captureFirstElement = function (ast) {
            elements.push(ast.children[0].tagName);
        };
        processor.plugins = [function () { return captureFirstElement; }];
        var docs = [
            { docType: 'a', renderedContent: '<a></a>' },
            { docType: 'b', renderedContent: '<b></b>' },
            { docType: 'c', renderedContent: '<c></c>' },
            { docType: 'd', renderedContent: '<d></d>' },
        ];
        processor.$process(docs);
        expect(elements).toEqual(['a', 'b']);
    });
    it('should run all the plugins on each doc', function () {
        var capitalizeFirstElement = function (ast) {
            ast.children[0].tagName = ast.children[0].tagName.toUpperCase();
        };
        var addOneToFirstElement = function (ast) {
            ast.children[0].tagName = ast.children[0].tagName + '1';
        };
        var elements = [];
        var captureFirstElement = function (ast) {
            elements.push(ast.children[0].tagName);
        };
        var docs = [
            { docType: 'a', renderedContent: '<a></a>' },
            { docType: 'b', renderedContent: '<b></b>' },
            { docType: 'c', renderedContent: '<c></c>' },
            { docType: 'd', renderedContent: '<d></d>' },
        ];
        processor.plugins = [
            function () { return capitalizeFirstElement; },
            function () { return addOneToFirstElement; },
            function () { return captureFirstElement; },
        ];
        processor.$process(docs);
        expect(elements).toEqual(['A1', 'B1']);
    });
    it('should report non-fatal errors', function () {
        var log = injector.get('log');
        var addWarning = function (_, file) {
            file.message('There was a problem');
        };
        processor.plugins = [function () { return addWarning; }];
        processor.$process([{ docType: 'a', renderedContent: '' }]);
        expect(log.warn).toHaveBeenCalledWith('There was a problem - doc (a) ');
    });
    it('should throw on fatal errors', function () {
        var log = injector.get('log');
        var addError = function (_, file) {
            file.fail('There was an error');
        };
        var doc = { docType: 'a', renderedContent: '' };
        processor.plugins = [function () { return addError; }];
        expect(function () { return processor.$process([doc]); }).toThrowError(createDocMessage('There was an error', doc));
        expect(log.error).not.toHaveBeenCalled();
    });
});
//# sourceMappingURL=postProcessHtml.spec.js.map