"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = require(".");
var getTypeText_1 = require("./getTypeText");
var path = require('canonical-path');
describe('getTypeText', function () {
    var parser;
    var basePath;
    beforeEach(function () {
        parser = new _1.TsParser(require('dgeni/lib/mocks/log')(false));
        basePath = path.resolve(__dirname, '../../mocks');
    });
    it('should return text representation of types', function () {
        var parseInfo = parser.parse(['tsParser/getTypeText.test.ts'], basePath);
        var moduleExports = parseInfo.moduleSymbols[0].exportArray;
        expect(moduleExports.length).toEqual(13);
        var types = moduleExports.map(function (e) { return [e.name, getType(e) && getTypeText_1.getTypeText(getType(e))]; });
        expect(types).toContain(['TestType', 'TestClass']);
        expect(types).toContain(['testFunction', 'string']);
        expect(types).toContain(['testConst', 'number']);
        expect(types).toContain(['testLet', 'TestType']);
        expect(types).toContain(['TestUnion', 'TestClass | string']);
        expect(types).toContain(['TestLiteral', [
                '{',
                '    x: number;',
                '    y: string;',
                '}',
            ].join('\n')]);
        expect(types).toContain(['TestGeneric1', 'Array<string>']);
        expect(types).toContain(['TestGeneric2', 'Array<T>']);
    });
    it('should remove comments from the rendered text', function () {
        var parseInfo = parser.parse(['tsParser/getTypeText.test.ts'], basePath);
        var moduleExports = parseInfo.moduleSymbols[0].exportArray;
        var testType2 = moduleExports.find(function (e) { return e.name === 'TestType2'; });
        expect(getTypeText_1.getTypeText(getType(testType2))).toEqual([
            '{',
            '    a: number;',
            '    b: string;',
            '} & {',
            '    a: string;',
            '}',
        ].join('\n'));
    });
});
function getType(symbol) {
    return symbol.getDeclarations()[0].type;
}
//# sourceMappingURL=getTypeText.spec.js.map